<?php

require_once(__DIR__ . '/../../../api/controller.php');
require_once(__DIR__ . '/../../../rest/oauth/OAuth2StorageUserCredential.php');

class DynamicContactResourceTest extends PHPUnit_Framework_TestCase {

    private $classOAuth = null;
    private $user = 'user2';
    private $pass = 'prognus';
    private $accessToken = 'aaaaaa259f553ac148f01b6bbcbb101';
    private $refreshToken = 'rrrrrr03fff3b8cdc51206244529agb';
    private $url = 'http://expressodev.prognus.com.br/acoutinho/expressoAPI/rest/dynamiccontacts';
    private $curlOPT;
    private $client_id = 666;
    private $user_id = 666;

    public function setUp() {
	$this->classOAuth = new OAuth2StorageUserCredential();
	session_id('rrrrrr03fff3b8cdc51206244529agb');

	$_SESSION['wallet']['user']['uid'] = $this->user;
	$_SESSION['wallet']['user']['password'] = $this->pass;
	$_SESSION['wallet']['user']['uidNumber'] = 42798;
	//insere access token
	$this->classOAuth->setAccessToken($this->accessToken, $this->client_id, $this->user_id, (time() + 3600), 'all', $this->refreshToken);

	//insere refresh token
	$this->classOAuth->setRefreshToken($this->refreshToken, $this->client_id, $this->user_id, (time() + 3600), 'all');
	$this->curlOPT = array(CURLOPT_URL => $this->url, CURLOPT_HEADER => 0, CURLOPT_RETURNTRANSFER => TRUE, CURLOPT_TIMEOUT => 4, CURLOPT_HTTPHEADER => array('Authorization: OAUTH Bearer aaaaaa259f553ac148f01b6bbcbb101'));
    }

    public function testcreateResource() {

	for ($i = 0; $i < 20; $i++) {
	    Controller::service('PostgreSQL')->execResultSql("INSERT INTO expressomail_dynamic_contact (owner, name, mail, timestamp) values 
		('42798', 'nameTeste" . $i . "', 'name" . $i . "@teste.com', '" . time() . "000');");
	}
	Controller::commit(array('service' => 'PostgreSQL'));
    }

    public function testCheckMaxResource() {
	$c = curl_init();
	curl_setopt_array($c, $this->curlOPT);
	$r = curl_exec($c);
	curl_close($c);

	$body = json_decode($r, true);
	$this->assertCount(20, $body['collection']['items']);
    }

    public function testCheckResource() {
	$c = curl_init();
	curl_setopt_array($c, $this->curlOPT);
	$r = curl_exec($c);
	curl_close($c);

	$body = json_decode($r, true);

	$this->assertArrayHasKey('collection', $body);
	$this->assertArrayHasKey('data', $body['collection']);
	$this->assertArrayHasKey('name', $body['collection']['data']);
	$this->assertArrayHasKey('prompt', $body['collection']['data']);
	$this->assertArrayHasKey('error', $body['collection']);
	$this->assertArrayHasKey('href', $body['collection']);
	$this->assertArrayHasKey('items', $body['collection']);
	$this->assertArrayHasKey('pagination', $body['collection']);
	$this->assertArrayHasKey('queries', $body['collection']);
	$this->assertArrayHasKey('template', $body['collection']);
	$this->assertArrayHasKey('dataType', $body['collection']['template']['data'][0]);
	$this->assertArrayHasKey('maxLength', $body['collection']['template']['data'][0]);
	$this->assertArrayHasKey('minLength', $body['collection']['template']['data'][0]);
	$this->assertArrayHasKey('name', $body['collection']['template']['data'][0]);
	$this->assertArrayHasKey('prompt', $body['collection']['template']['data'][0]);
	$this->assertArrayHasKey('value', $body['collection']['template']['data'][0]);
	$this->assertArrayHasKey('type', $body['collection']);
	$this->assertArrayHasKey('version', $body);
    }

    public function testCreateNewResource() {

	$data = array('name' => 'testUnitrio', 'email' => 'teste@unitario.com.br');
	$this->curlOPT[CURLOPT_URL] = $this->curlOPT[CURLOPT_URL];
	$c = curl_init();
	curl_setopt_array($c, $this->curlOPT);
	curl_setopt($c, CURLOPT_POSTFIELDS, $data);
	curl_setopt($c, CURLOPT_CUSTOMREQUEST, "POST");
	$r = curl_exec($c);
	curl_close($c);
	$body = json_decode($r, true);

	$this->assertNull($body);
    }

    public function testCreateInvalidNewResource() {

	$data = array('name' => 'testUnitrio', 'emailinvalido' => 'teste@unitario.com.br');
	$this->curlOPT[CURLOPT_URL] = $this->curlOPT[CURLOPT_URL];
	$c = curl_init();
	curl_setopt_array($c, $this->curlOPT);
	curl_setopt($c, CURLOPT_POSTFIELDS, $data);
	curl_setopt($c, CURLOPT_CUSTOMREQUEST, "POST");
	$r = curl_exec($c);
	curl_close($c);
	$body = json_decode($r, true);

	$this->assertArrayHasKey('version', $body);
	$this->assertArrayHasKey('collection', $body);
	$this->assertArrayHasKey('code', $body['collection']['error']);
	$this->assertArrayHasKey('title', $body['collection']['error']);
	$this->assertArrayHasKey('description', $body['collection']['error']);
    }

    public function testCheckFinish() {
	Controller::service('PostgreSQL')->execResultSql("DELETE from expressomail_dynamic_contact where owner = ('42798')");

	$c = curl_init();
	curl_setopt_array($c, $this->curlOPT);
	$r = curl_exec($c);
	curl_close($c);
	$body = json_decode($r, true);

	$this->assertNull($body['collection']['items']);
    }

    public function tearDown() {
	$this->classOAuth->unsetRefreshToken($this->refreshToken);
	$this->classOAuth->unsetAccessToken($this->accessToken);
    }

}

?>
